@@ -1,11 +1,11 @@
 #!/bin/bash
 # Copyright (c) 2020 Red Hat, Inc.
 
-git config --global url."https://$GITHUB_TOKEN@github.com/open-cluster-management".insteadOf  "https://github.com/open-cluster-management"
+git config --global url."https://$GITHUB_TOKEN@github.com/stolostron".insteadOf  "https://github.com/stolostron"
 
 WORKDIR=`pwd`
 cd ${WORKDIR}/..
-git clone https://github.com/open-cluster-management/observability-kind-cluster.git
+git clone https://github.com/stolostron/observability-kind-cluster.git
 cd observability-kind-cluster
 ./setup.sh $1
 if [ $? -ne 0 ]; then
@@ -14,7 +14,7 @@ if [ $? -ne 0 ]; then
 fi
 
 cd ${WORKDIR}/..
-git clone https://github.com/open-cluster-management/observability-e2e-test.git
+git clone https://github.com/stolostron/observability-e2e-test.git
 cd observability-e2e-test
 git checkout release-2.2
 
