@@ -18,7 +18,7 @@ import (
 	"k8s.io/klog"
 	"sigs.k8s.io/controller-runtime/pkg/client/config"
 
-	"github.com/open-cluster-management/rbac-query-proxy/pkg/util"
+	"github.com/stolostron/rbac-query-proxy/pkg/util"
 )
 
 const (
